==> kubernetes-model-networking-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/IngressServiceBackendBuilder.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IngressServiceBackendBuilder extends IngressServiceBackendFluentImpl<IngressServiceBackendBuilder> implements VisitableBuilder<IngressServiceBackend,IngressServiceBackendBuilder>{
  public IngressServiceBackendBuilder() {
    this(false);
  }
  public IngressServiceBackendBuilder(Boolean validationEnabled) {
    this(new IngressServiceBackend(), validationEnabled);
  }
  public IngressServiceBackendBuilder(IngressServiceBackendFluent<?> fluent) {
    this(fluent, false);
  }
  public IngressServiceBackendBuilder(IngressServiceBackendFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IngressServiceBackend(), validationEnabled);
  }
  public IngressServiceBackendBuilder(IngressServiceBackendFluent<?> fluent,IngressServiceBackend instance) {
    this(fluent, instance, false);
  }
  public IngressServiceBackendBuilder(IngressServiceBackendFluent<?> fluent,IngressServiceBackend instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withPort(instance.getPort());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public IngressServiceBackendBuilder(IngressServiceBackend instance) {
    this(instance,false);
  }
  public IngressServiceBackendBuilder(IngressServiceBackend instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withName(instance.getName());
      this.withPort(instance.getPort());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  IngressServiceBackendFluent<?> fluent;
  Boolean validationEnabled;
  public IngressServiceBackend build() {
    IngressServiceBackend buildable = new IngressServiceBackend(fluent.getName(),fluent.getPort());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-networking-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/IngressServiceBackendBuilder.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IngressServiceBackendBuilder extends IngressServiceBackendFluent<IngressServiceBackendBuilder> implements VisitableBuilder<IngressServiceBackend,IngressServiceBackendBuilder>{
  public IngressServiceBackendBuilder() {
    this(false);
  }
  public IngressServiceBackendBuilder(Boolean validationEnabled) {
    this(new IngressServiceBackend(), validationEnabled);
  }
  public IngressServiceBackendBuilder(IngressServiceBackendFluent<?> fluent) {
    this(fluent, false);
  }
  public IngressServiceBackendBuilder(IngressServiceBackendFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IngressServiceBackend(), validationEnabled);
  }
  public IngressServiceBackendBuilder(IngressServiceBackendFluent<?> fluent,IngressServiceBackend instance) {
    this(fluent, instance, false);
  }
  public IngressServiceBackendBuilder(IngressServiceBackendFluent<?> fluent,IngressServiceBackend instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new IngressServiceBackend());

    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withPort(instance.getPort());
      fluent.withName(instance.getName());
      fluent.withPort(instance.getPort());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public IngressServiceBackendBuilder(IngressServiceBackend instance) {
    this(instance,false);
  }
  public IngressServiceBackendBuilder(IngressServiceBackend instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new IngressServiceBackend());

    if (instance != null) {
      this.withName(instance.getName());
      this.withPort(instance.getPort());
      this.withName(instance.getName());
      this.withPort(instance.getPort());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  IngressServiceBackendFluent<?> fluent;
  Boolean validationEnabled;
  public IngressServiceBackend build() {
    IngressServiceBackend buildable = new IngressServiceBackend(fluent.getName(),fluent.buildPort());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
